Overriding templates — django-nomadblog 0.5 documentation

### Navigation

- index
- next |
- previous |
- django-nomadblog 0.5 documentation »

# Overriding templates

`django-nomadblog` uses different templates to list posts, show a post details, list categories or list posts by category. You will want to override these templates, to add your layout, design and own stuff. Create a new `nomadblog` template folder where your project can find it and copy the templates found on the `templates/nomadblog` directory (like `list_posts.html` or `show_post.html`) or, if you want to be quicker, just copy the entire `templates/nomadblog` folder.

### Navigation

- index
- next |
- previous |
- django-nomadblog 0.5 documentation »